Learn R Programming

IHSEP (version 0.3.1)

sepp.resid: Calculate the self exciting point process residuals

Description

Calculate the self exciting point process residuals

Usage

sepp.resid(jtms, Tau, Inu, Ig)

Value

A numerical vector containing the SEPP residuals \(\Lambda(t_i)\) where \(\Lambda\) is the cumulative intensity process.

Arguments

jtms

A numerical vector containing the event times of the SEPP in ascending order

Tau

A numerical scalar giving the censoring time, which should be greater than or equal to the event time

Inu

A function that gives the integral of the baseline event rate function \(\nu(t)\) from 0 to the argument of the function

Ig

A function that gives the integral of the excitation function \(g(t)\) from 0 to the argument of the function