A list of vectors of arrival/birth times of individuals/events of
generations 0, 1, ... The length of the list is the total number of
generations.
Arguments
nu
A (vectorized) function. The baseline intensity function.
g
A (vectorized) function. The excitation function.
cens
A scalar. The censoring time, or the time of termination of observations.
nuM
A scalar. The maximum time of the baseline intensity from 0 to cens.
gM
A scalar. The maximum time of the excitation function from 0 to cens.
exp.g
A logical. Whether the excitation function g should be treated as an
exponential function.
gp
A vector of two elements, giving the two parameters a and b in the
exponential excitation function \(g(x)=a*exp(-b*x)\), which is
used when exp.g is set to TRUE, and is ignored otherwise.
Author
Feng Chen <feng.chen@unsw.edu.au>
Details
The function works by simulating the birth times generation by
generation according to inhomegenous Poisson processes with
appropriate intensity functions (\(\nu\) or \(g\)).