Calculate the self exciting point process residuals
sepp.resid(jtms, Tau, Inu, Ig)A numerical vector containing the SEPP residuals \(\Lambda(t_i)\) where \(\Lambda\) is the cumulative intensity process.
A numerical vector containing the event times of the SEPP in ascending order
A numerical scalar giving the censoring time, which should be greater than or equal to the event time
A function that gives the integral of the baseline event rate function \(\nu(t)\) from 0 to the argument of the function
A function that gives the integral of the excitation function \(g(t)\) from 0 to the argument of the function