simHawkes0: Simulate a Hawkes process, or Self-exciting point process
Description
Simulate an (inhomogeneous) self-exciting process with given background
intensity and excitation/fertility function.
Usage
simHawkes0(nu, g, cens = 1,
nuM=max(optimize(nu,c(0,cens),maximum=TRUE)$obj,nu(0),nu(cens))*1.1,
gM=max(optimize(g,c(0,cens),maximum=TRUE)$obj, g(0),g(cens))*1.1)
Value
A list of vectors of arrival/birth times of individuals/events of
generations 0, 1, ....
Arguments
nu
A (vectorized) function. The baseline intensity function.
g
A (vectorized) function. The excitation function.
cens
A scalar. The censoring time, or the time of termination of observations.
nuM
A scalar. The maximum time of the baseline intensity from 0 to cens.
gM
A scalar. The maximum time of the excitation function from 0 to cens.
Author
Feng Chen <feng.chen@unsw.edu.au>
Details
The function works by simulating the birth times generation by
generation according to inhomegenous Poisson processes with
appropriate intensity functions (\(\nu\) or \(g\)).